
--[[

A Stat Overview Menu specifies the stat overview 
specific options that should appear in the context
menu when a Stat Overview Tab is right clicked.

Options are available to show or hide various
aspects of the tab's current Stat Overview window.
An additional option allows the player's information
to be automatically selected, and an option is
provided that allows the totals encounter to be
reset.

]]--

_G.StatOverviewTabMenu = class(CombatAnalysisTabMenu);

function StatOverviewTabMenu:Constructor()
	CombatAnalysisTabMenu.Constructor(self);
	
	self.autoSelectPlayer = Turbine.UI.MenuItem(L.AutoSelectPlayer,true,false);
	self.items:Insert(4,self.autoSelectPlayer);
	self.autoSelectInList = true;
	
	self.showMainTitleBar = Turbine.UI.MenuItem(L.ShowTitleAndDuration,true,true);
	self.showEncounters = Turbine.UI.MenuItem(L.ShowEncountersList,true,true);
	self.showTargets = Turbine.UI.MenuItem(L.ShowTargetsList,true,true);
	self.showSendChat = Turbine.UI.MenuItem(L.ShowExtraButtons,true,true);
	
	self.resetTotals = Turbine.UI.MenuItem(L.ResetTotals);
	self.resetTotals.Click = function(sender,args)
		if (confirmOnReset) then
			dialog:ShowConfirmDialog(L.ResetTotalsMessage,combatData.ResetTotals,combatData);
		else
			combatData:ResetTotals(true);
		end
	end
	
	self.items:Add(self.showMainTitleBar);
	self.items:Add(self.showEncounters);
	self.items:Add(self.showTargets);
	self.items:Add(self.showSendChat);
	self.items:Add(self.resetTotals);
end

function StatOverviewTabMenu:PopulateMenu(tab)
	CombatAnalysisTabMenu.PopulateMenu(self,tab);
	
	if (tab.isBuffTab) then
		if (self.autoSelectInList) then self.items:RemoveAt(4) end
		self.autoSelectInList = false;
		
	else
		if (not self.autoSelectInList) then self.items:Insert(4,self.autoSelectPlayer) end
		self.autoSelectInList = true;
		
		self.autoSelectPlayer:SetChecked(tab.autoSelectPlayer);
		self.autoSelectPlayer.Click = function(sender,args)
			self.autoSelectPlayer:SetChecked(not self.autoSelectPlayer:IsChecked());
			tab.autoSelectPlayer = self.autoSelectPlayer:IsChecked();
			tab:SaveState();
		end
	end
	
	self.showMainTitleBar:SetChecked(tab.showTitle);
	self.showMainTitleBar.Click = function(sender,args)
		self.showMainTitleBar:SetChecked(not self.showMainTitleBar:IsChecked());
		tab:SetAllTabsShowTitle(self.showMainTitleBar:IsChecked());
	end
	
	self.showEncounters:SetChecked(tab.showEncounters);
	self.showEncounters.Click = function(sender,args)
		self.showEncounters:SetChecked(not self.showEncounters:IsChecked());
		tab:SetAllTabsShowEncounters(self.showEncounters:IsChecked());
	end
	
	self.showTargets:SetChecked(tab.showTargets);
	self.showTargets.Click = function(sender,args)
		self.showTargets:SetChecked(not self.showTargets:IsChecked());
		tab:SetAllTabsShowTargets(self.showTargets:IsChecked());
	end
	
	self.showSendChat:SetChecked(tab.showSendChat);
	self.showSendChat.Click = function(sender,args)
		self.showSendChat:SetChecked(not self.showSendChat:IsChecked());
		tab:SetAllTabsShowSendChat(self.showSendChat:IsChecked());
	end
end
